<?php
/*
 * Public Domain
 */
if (!defined('NOT_ACCESSED_DIRECTLY')) exit('This file may not be directly accessed');

//Your module's directory needs to contain a PHP file named module_code.php. This file
//should contain a PHP class definition, which should contain your module's program
//code.

//The class name you use MUST match your module's directory name.

//Your class should either extend the module_base_class, or else extend another module
//that extends the module_base_class.
//If you extend another module, you must list that module as a dependancy in your
//description.yaml file. The CMS will then check if the module you are extending can be
//run and include it for you each time the code your module is included; you do not
//need to use "include" or "require" in your code to include the module you are
//extending.


class example_module_3 extends module_base_class {
	
	//Your init() method is called before a page with your plugin on it is displayed.
	//You should set up your plugin, handle any form submissions that your plugin
	//accepts, then return true.
	//Alternately you can return false to hide your plugin from Visitors (but Admins
	//will always see your plugin).
	public function init() {
		
		//Don't allow this plugin to be cached, as its output is dependant on the
		//current time.
		$this->allowCaching($atAll = false);
		
		return true;
	}
	
	//Your showSlot() method is called by the CMS whenever it needs to display your
	//plugin in a Slot. It's your chance to display whatever you like, and have it
	//appear on the page!
	public function showSlot() {
		
		//The phrase() function can be used to look up the local text of one of your
		//phrases in the visitor's language.
		//E.g.
			//echo $this->phrase('_DAY_1')
		//is the same as putting
			//{{'_DAY_1' |trans}}
		//in your framework. 
		//In your module code you can also use phrases from other
		//modules, such as days of the week which are defined in zenario_common_features
		$today = date('w');
		$mergeFields = array();
		$mergeFields['Today'] = phrase('_WEEKDAY_'. $today, array(), 'zenario_common_features');
		
		
		//The setting() function will look up the value of one of your plugin settings.
		//In this case we will conditionally show the next day, depending on whether
		//the "Show next day" checkbox was checked in the plugin settings.
		if ($this->setting('show_next_day')) {
			$tomorrow = ($today % 7) + 1;
			$mergeFields['Tomorrow'] = phrase('_WEEKDAY_'. $tomorrow, array(), 'zenario_common_features');
		}
		
		
		//The twigFramework() function can be used to display your framework.twig.html file.
		//You can enter an array of data in the first parameter to pass that data on to your Twig framework.
		$this->twigFramework($mergeFields);
	}
}